@@ -18,6 +18,12 @@ a <- ggplot(data = sample_df, mapping = aes(x = group, y = value)) +
 aa <- list(a, a)
 
 
+test_that("Test decoreate.grob not to throw", {
+  p <- ggplotGrob(a)
+  expect_no_error(decorate.grob(p, titles = "some title", footnotes = "some footnote"))
+})
+
+
 test_that("Test decoreate not to throw", {
   # test for decorate.autoslider_error
   e <- autoslider_error("error", list(program = "", suffix = ""), step = "test")
@@ -44,3 +50,18 @@ test_that("Test print not to throw", {
 test_that("Test decoreate throw", {
   expect_error(decorate.default(e), "default decorate function does not exist", ignore.case = TRUE)
 })
+
+
+test_that("Test ph_with_img not to throw", {
+  p <- ggplotGrob(a)
+  location_ <- officer::fortify_location(officer::ph_location_fullsize(), doc = read_pptx())
+  width <- location_$width
+  height <- location_$height
+  fig_width <- 9
+  fig_height <- 6
+  figure_loc <- autoslider.core:::center_figure_loc(fig_width, fig_height, ppt_width = width, ppt_height = height)
+  ppt <- read_pptx()
+  ppt_master <- layout_summary(ppt)$master[1]
+  ppt <- do_call(add_slide, x = ppt, master = ppt_master)
+  expect_no_error(ph_with_img(ppt, p, fig_width, fig_height, figure_loc))
+})
