@@ -1,8 +1,9 @@
-library(filters)
-
 test_that("Listing print correctly", {
   # skip_if_too_deep(1)
-  load_filters(file.path(system.file(package = "autoslider.core"), "filters.yml"), overwrite = TRUE)
+  filters::load_filters(file.path(
+    system.file(package = "autoslider.core"),
+    "filters.yml"
+  ), overwrite = TRUE)
 
   spec_file <- file.path(system.file(package = "autoslider.core"), "spec.yml")
 
